@@ -1,7 +1,7 @@
 
 
 jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chains,n.adapt=100,n.iter,n.burnin=0,n.thin=1,
-                       modules=c('glm'),parallel=FALSE,DIC=TRUE,store.data=FALSE,codaOnly=FALSE,seed=floor(runif(1,1,10000)),
+                       modules=c('glm'),parallel=FALSE,n.cores=NULL,DIC=TRUE,store.data=FALSE,codaOnly=FALSE,seed=floor(runif(1,1,10000)),
                        bugs.format=FALSE,verbose=TRUE){
   
   #Set random seed
@@ -9,10 +9,11 @@ jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chain
   set.seed(seed)
   
   #Pass input data and parameter list through error check / processing
-  data.check <- process.input(data,parameters.to.save,inits,n.chains,n.iter,n.burnin,n.thin,DIC=DIC,verbose=verbose)
+  data.check <- process.input(data,parameters.to.save,inits,n.chains,n.iter,n.burnin,n.thin,n.cores,DIC=DIC,verbose=verbose,parallel=parallel)
   data <- data.check$data
   parameters.to.save <- data.check$params
   inits <- data.check$inits
+  if(parallel){n.cores <- data.check$n.cores}
   
   #Save start time
   start.time <- Sys.time()
@@ -21,7 +22,7 @@ jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chain
   if(parallel && n.chains>1){
  
   par <- run.parallel(data,inits,parameters.to.save,model.file,n.chains,n.adapt,n.iter,n.burnin,n.thin,
-                      modules,seed,DIC,verbose=verbose) 
+                      modules,seed,DIC,verbose=verbose,n.cores=n.cores) 
   samples <- par$samples
   m <- par$model
     
@@ -54,10 +55,12 @@ jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chain
   end.values <- samples[(n.samples/n.chains),]
   mcmc.info <- list(n.chains,n.adapt,n.iter,n.burnin,n.thin,n.samples,end.values,time)
   names(mcmc.info) <- c('n.chains','n.adapt','n.iter','n.burnin','n.thin','n.samples','end.values','elapsed.mins')
-  
+  if(parallel){mcmc.info$n.cores <- n.cores}
   
   #Reorganize JAGS output to match input parameter order
-  samples <- order.params(samples,parameters.to.save,DIC,verbose=verbose)
+  if(dim(samples[[1]])[2]>1){
+    samples <- order.params(samples,parameters.to.save,DIC,verbose=verbose)
+  }
   
   #Convert rjags output to jagsUI form 
   output <- process.output(samples,DIC=DIC,codaOnly,verbose=verbose)
